@@ -69,7 +69,7 @@ void callwritenet(xcWidget w, pointertype mode, caddr_t calldata)
         writenet(topobject, "spice", "spc");
 	break;
      case 1:
-        writenet(topobject, "sim", "sim");
+        writenet(topobject, "flatsim", "sim");
 	break;
      case 2:
         writenet(topobject, "pcb", "pcbnet");
@@ -79,7 +79,7 @@ void callwritenet(xcWidget w, pointertype mode, caddr_t calldata)
 	break;
      case 4:
 	/* Auto-numbering:  no output generated */
-	writenet(topobject, "idxpcb", "");
+	writenet(topobject, "indexpcb", "");
 	break;
    }
 }
