@@ -473,7 +473,7 @@ selection *genselectelement(short class, u_char mode, objectptr selobj,
 
       else if ((*curgen)->type == (class & OBJINST)) {
 
-	 objinstbbox(TOOBJINST(curgen), newboxpts, True);
+	 objinstbbox(TOOBJINST(curgen), newboxpts, range);
 
          /* Look for an intersect of the boundingbox and pointer position. */
          /* This is a simple matter of rotating the pointer position with  */
