@@ -386,7 +386,7 @@ void register_for_undo(u_int type, u_char mode, objinstptr thisinst, ...)
    uselection *srec;
    editelement *erec;
    scaleinfo *escale;
-   genericptr egen, *ggen, *cgen;
+   genericptr egen;
    XPoint *fpoint;
    double scale;
 
@@ -812,7 +812,6 @@ short undo_one_action()
 	       int tmpnum;
 	       polyptr epoly;
 	       splineptr espline;
-	       pathinfo *tmpinfo = erec->save.pathspecs;
 	       pathptr epath = (pathptr)(erec->element);
 	       for (i = 0; i < epath->parts; i++) {
 		  genericptr ggen = *(epath->plist + i);
@@ -1188,7 +1187,6 @@ short redo_one_action()
 	       int tmpnum;
 	       polyptr epoly;
 	       splineptr espline;
-	       pathinfo *tmpinfo = erec->save.pathspecs;
 	       pathptr epath = (pathptr)(erec->element);
 	       for (i = 0; i < epath->parts; i++) {
 		  genericptr ggen = *(epath->plist + i);
